/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.client.common.config;

import java.util.Properties;


/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class CollectorConfig {
	
	public static final String ACTIVE = "active";
	public static final String COLLECTION_INTERVAL = "collectionInterval";
	public static final String COLLECTION_MAX_SAMPLES = "collectionMaxSamples";
	public static final String COLLECTION_SAMPLING = "collectionSampling";
	public static final String CPU_TIME_ENABLED = "cpuTimeEnabled";
	public static final String CPU_TIME_ALLOWED = "cpuTimeAllowed";
	public static final String CONTENTION_MONITORING_ENABLED = "contentionMonitoringEnabled";
	public static final String CONTENTION_MONITORING_ALLOWED = "contentionMonitoringAllowed";
	public static final String CONTENTION_MONITORING_INTERVAL = "contentionMonitoringInterval";
	
	public static final boolean DEFAULT_ACTIVE = true;
	public static final int DEFAULT_COLLECTION_INTERVAL = 5000;
	public static final int DEFAULT_COLLECTION_MAX_SAMPLES = 1000;
	public static final int DEFAULT_COLLECTION_SAMPLING = 1;
	public static final boolean DEFAULT_CPU_TIME_ENABLED = true;
	public static final boolean DEFAULT_CPU_TIME_ALLOWED = true;
	public static final boolean DEFAULT_CONTENTION_MONITORING_ENABLED = true;
	public static final boolean DEFAULT_CONTENTION_MONITORING_ALLOWED = true;
	public static final int DEFAULT_CONTENTION_MONITORING_INTERVAL = 50;
	
	protected Properties mProperties = null; 

	
	public CollectorConfig(Properties properties)
	{
		mProperties = properties;
	}
	
	public String getProperty(String key, String defaultValue)
	{
		return mProperties.getProperty(key, defaultValue);
	}
	
	public int getPropertyAsInt(String key, int defaultValue)
	{
		int result = defaultValue;
		try
		{
			result = Integer.valueOf(mProperties.getProperty(key));
		}
		catch (Exception ex)
		{
		}
		
		return result;
	}
	
	public boolean getPropertyAsBoolean(String key, boolean defaultValue)
	{
		boolean result = defaultValue;
		try
		{
			result = Boolean.valueOf(mProperties.getProperty(key));
		}
		catch (Exception ex)
		{
		}
		
		return result;
	}
	
	public Properties getProperties()
	{
		return mProperties;
	}
	
	/**
	 * @return the sampling
	 */
	public int getSampling() {
		return getPropertyAsInt(COLLECTION_SAMPLING, DEFAULT_COLLECTION_SAMPLING);
	}

	/**
	 * @param sampling
	 *            the sampling to set
	 */
	public void setSampling(int sampling) {
		mProperties.setProperty(COLLECTION_SAMPLING, String.valueOf(sampling));
	}

	/**
	 * @return the maxSamples
	 */
	public int getMaxSamples() {
		return getPropertyAsInt(COLLECTION_MAX_SAMPLES, DEFAULT_COLLECTION_MAX_SAMPLES);
	}

	/**
	 * @param maxSamples
	 *            the maxSamples to set
	 */
	public void setMaxSamples(int maxSamples) {
		mProperties.setProperty(COLLECTION_MAX_SAMPLES, String.valueOf(maxSamples));
	}
	
	public boolean getCpuTimeEnabled()
	{
		return getCpuTimeAllowed() && getPropertyAsBoolean(CPU_TIME_ENABLED, DEFAULT_CPU_TIME_ENABLED);
	}
	
	public boolean getCpuTimeAllowed()
	{
		return getPropertyAsBoolean(CPU_TIME_ALLOWED, DEFAULT_CPU_TIME_ALLOWED);
	}
	
	public boolean getThreadContentionEnabled()
	{
		return getThreadContentionAllowed() && getPropertyAsBoolean(CONTENTION_MONITORING_ENABLED, DEFAULT_CONTENTION_MONITORING_ENABLED);
	}
	
	public boolean getThreadContentionAllowed()
	{
		return getPropertyAsBoolean(CONTENTION_MONITORING_ALLOWED, DEFAULT_CONTENTION_MONITORING_ALLOWED);
	}
}
